@@ -15,8 +15,11 @@
 from __future__ import annotations
 
 import firefly_di as di
+import firefly_messaging.domain as domain
 import firefly_messaging.infrastructure as infra
 
 
 class Container(di.Container):
-    mailchimp_email_service: infra.MailchimpEmailService
+    email_service_factory: domain.EmailServiceFactory = infra.EmailServiceFactory
+    email_service: infra.EmailService = infra.EmailService
+    mailchimp_email_service: infra.MailchimpEmailService = infra.MailchimpEmailService
